from datanews.requestor import Requestor

BASE_URL = 'http://api.datanews.io/v1/monitors/%s'


class Monitor(object):
    @staticmethod
    def create(query='', webhook=''):
        if not query:
            raise ValueError('Query must not be empty.')
        url = BASE_URL % 'create'
        return Requestor().request('post', url=url, data={'query': query, 'webhook': webhook})

    @staticmethod
    def list():
        url = BASE_URL % 'list'
        return Requestor().request('get', url=url)

    @staticmethod
    def get(id):
        Monitor._validate_id(id, 'Monitor id should not be None.')
        url = BASE_URL % ('/list/%s' % id)
        return Requestor().request('get', url)

    @staticmethod
    def delete(id):
        Monitor._validate_id(id, 'Monitor id should not be None.')
        url = BASE_URL % ('/delete/%s' % id)
        return Requestor().request('delete', url=url)

    @staticmethod
    def latest(run_id):
        Monitor._validate_id(run_id, 'Run id should not be None.')
        url = BASE_URL % ('/latest/%s' % run_id)
        return Requestor().request('get', url=url)

    @staticmethod
    def _validate_id(id, message):
        if not id:
            raise ValueError(message)



import datanews
import requests

from urllib.parse import urlencode


class Requestor(object):
    def __init__(self):
        self.api_key = datanews.api_key

    def request(self, method, url, params=None, data=None):
        self._validate_key(self.api_key)
        if method == 'get':
            return self._get(url, params)
        elif method == 'post':
            return self._post(url, data)
        elif method == 'delete':
            return self._delete(url, data)
        else:
            raise ValueError('Invalid method value \'%s\'' % method)

    def _get(self, url, params):
        if params:
            qstring = urlencode(params, doseq=True)
            url = url + '?' + qstring
        return self._handle_response(
            requests.get(url, headers=self._build_headers()))

    def _post(self, url, data):
        return self._handle_response(
            requests.post(url, json=data, headers=self._build_headers()))

    def _delete(self, url, data):
        return self._handle_response(
            requests.delete(url, json=data, headers=self._build_headers()))

    def _build_headers(self):
        headers = {'x-api-key': self.api_key}
        return headers

    @staticmethod
    def _validate_key(api_key):
        if not api_key or type(api_key) is not str:
            raise ValueError('Invalid api ley \'%s\'' % api_key)

    @staticmethod
    def _handle_response(response):
        return response.json()



from datanews.requestor import Requestor

BASE_URL = 'http://api.datanews.io/v1/%s'


def _build_params(params, q=None, from_date=None, to_date=None, source=None, country=None, language=None, topic=None, page=None, size=None, sortBy=None):
    if q is not None:
        if type(q) is not str:
            raise ValueError('Query must be a string object.')
        params['q'] = q

    if from_date is not None:
        if type(from_date) is not str:
            raise ValueError('From date must be a string object.')
        params['from'] = from_date

    if to_date is not None:
        if type(to_date) is not str:
            raise ValueError('To date must be a string object.')
        params['to'] = to_date

    if source is not None:
        if type(source) is str:
            source = [source]
        elif type(source) is not list:
            raise ValueError('Source must be a string or a list of strings object.')
        params['source'] = source

    if country is not None:
        if type(country) is str:
            country = [country]
        elif type(country) is not list:
            raise ValueError('Source must be a string or a list of strings object.')
        params['country'] = country

    if language is not None:
        if type(language) is str:
            language = [language]
        elif type(language) is not list:
            raise ValueError('Source must be a string or a list of strings object.')
        params['language'] = language

    if topic is not None:
        if type(topic) is str:
            topic = [topic]
        elif type(topic) is not list:
            raise ValueError('Source must be a string or a list of strings object.')
        params['topic'] = topic

    if page is not None:
        if type(page) is not int or page < 0:
            raise ValueError('Page must be a positive integer.')
        params['page'] = page

    if size is not None:
        if type(size) is not int or (size < 0 or size > 100):
            raise ValueError('Size must be a positive integer from 1 to 100.')
        params['size'] = size

    if sortBy is not None:
        if sortBy != 'relevance' and sortBy != 'date':
            raise ValueError('SortBy must equal \'relevance\' or \'date\'')
        params['sortBy'] = sortBy

    return params


def headlines(q=None, source=None, country=None, language=None, topic=None, page=None, size=None, sortBy=None):
    url = BASE_URL % 'headlines'
    params = {}
    _build_params(params, q=q, source=source, country=country, language=language, topic=topic,
                  page=page, size=size, sortBy=sortBy)
    return Requestor().request('get', url=url, params=params)


def news(q=None, from_date=None, to_date=None, source=None, country=None, language=None, topic=None,
         page=None, size=None, sortBy=None):
    url = BASE_URL % 'news'
    params = {}
    _build_params(params, q=q, from_date=from_date, to_date=to_date, source=source, country=country, language=language,
                  topic=topic, page=page, size=size, sortBy=sortBy)
    return Requestor().request('get', url=url, params=params)


def sources(country=None, language=None, topic=None, page=None, size=None):
    url = BASE_URL % 'sources'
    params = {}
    _build_params(params, country=country, language=language, topic=topic, page=page, size=size)
    return Requestor().request('get', url=url, params=params)



from setuptools import setup
from setuptools import find_packages

with open('README.md', 'r') as f:
    long_description = f.read()

with open('requirements.txt', 'r') as f:
    required = f.read().splitlines()

setup(
    name='datanews',
    version="0.0.5",
    author="Vladyslav Mokrousov",
    author_email="mokrousov@datanews.io",
    description="Python client library for Datanews API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/DatanewsOrg/datanews-python",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
    install_requires=required
)
